<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>ActionShowStashDelegate</name>
    <message>
        <source>Application tray</source>
        <translation>应用托盘</translation>
    </message>
</context>
<context>
    <name>ActionToggleCollapseDelegate</name>
    <message>
        <source>Collapse tray</source>
        <translation>折叠托盘</translation>
    </message>
</context>
<context>
    <name>PanelTrayItem</name>
    <message>
        <source>Quick actions</source>
        <translation>快捷设置</translation>
    </message>
</context>
</TS>